#!/bin/sh
# Trivial script to run conformance tests for cmd.exe
# on either Windows or Wine
# See also cmd_test.c, which does roughly the same thing,
# but embeds the same test scripts in the executable.
#
# To run on Windows, install cygwin (and inside cygwin's
# setup, install Utils / diffutils)

set -e
set -x

case "$OS" in
 "Windows_NT")
    WINE=""
    ;;
 *)
    WINE=${WINE:-wine}
    ;;
esac

check() {
   if test -f $name.$1.exp
   then
      diff -b -u $name.$1.exp $name.$1 
   else
      true
   fi
}

export WINEDEBUG=-all

failures=0
for script in test*.cmd
do
   name=`basename $script .cmd`
   if $WINE cmd /c $script > $name.out 2> $name.err && check out && check err
   then
       echo test $name passed
       rm $name.out $name.err
   else
       echo test $name failed
       failures=`expr $failures + 1`
   fi
done

case $failures in
0) echo All tests passed.; exit 0;;
esac
echo $failures tests failed.
exit 1
